Web Clusters
============

.. contents:: :local:

-------------


WebCluster
----------

* :class:`cfxdb.mrealm.WebCluster`
* :class:`cfxdb.mrealmschema.WebClusters`
* :class:`cfxdb.mrealmschema.IndexWebClusterByName`
* :class:`cfxdb.mrealm.WebClusterNodeMembership`
* :class:`cfxdb.mrealmschema.WebClusterNodeMemberships`

-------

.. autoclass:: cfxdb.mrealm.WebCluster
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.mrealmschema.WebClusters
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.mrealmschema.IndexWebClusterByName
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.mrealm.WebClusterNodeMembership
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.mrealmschema.WebClusterNodeMemberships
    :members:
    :show-inheritance:


WebService
----------

* :class:`cfxdb.mrealm.WebService`
* :class:`cfxdb.mrealmschema.WebServices`
* :class:`cfxdb.mrealmschema.IndexWebServiceByPath`
* :class:`cfxdb.mrealmschema.IndexWebClusterWebServices`

-------

.. autoclass:: cfxdb.mrealm.WebService
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.mrealmschema.WebServices
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.mrealmschema.IndexWebServiceByPath
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.mrealmschema.IndexWebClusterWebServices
    :members:
    :show-inheritance:
